GossipCat, A Cat Who Is Always Gossiping
========================================

😸😹😺😻😼😽😾😿🙀🐱

GossipCat is a machine learning framework that simplifies the process of machine learning from data cleaning, simple feature engineering, hyper parameter tuning, to results outputing. It is designed to be efficient with the following features:

- Combine the feature engineering and parameter tuning.
- Automate parameter tuning with algorithms.
- Provide accesses of the highist efficient machine learning algorithms.

Story of the GossipCat
----------------------

The package names after a cat of my friend, LEEverpool. Actually, the GossipCat is the name of a WeChat group, where my friends gossip there.

.. image:: https://raw.githubusercontent.com/Ewen2015/GossipCat/master/GossipCat.jpeg

License
-------

GossipCat is licensed under the Apache License 2.0. © Contributors, 2017.

A permissive license whose main conditions require preservation of copyright and license notices. Contributors provide an express grant of patent rights. Licensed works, modifications, and larger works may be distributed under different terms and without source code.
